Class: Google::Iam::V3::UpdatePolicyBindingRequest
- Inherits:
-
Object
- Object
- Google::Iam::V3::UpdatePolicyBindingRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/iam/v3/policy_bindings_service.rb
Overview
Request message for UpdatePolicyBinding method.
Instance Attribute Summary collapse
-
#policy_binding ⇒ ::Google::Iam::V3::PolicyBinding
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
-
#validate_only ⇒ ::Boolean
Optional.
Instance Attribute Details
#policy_binding ⇒ ::Google::Iam::V3::PolicyBinding
Returns Required. The policy binding to update.
The policy binding's name field is used to identify the policy binding to
update.
86 87 88 89 |
# File 'proto_docs/google/iam/v3/policy_bindings_service.rb', line 86 class UpdatePolicyBindingRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. The list of fields to update.
86 87 88 89 |
# File 'proto_docs/google/iam/v3/policy_bindings_service.rb', line 86 class UpdatePolicyBindingRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validate_only ⇒ ::Boolean
Returns Optional. If set, validate the request and preview the update, but do not actually post it.
86 87 88 89 |
# File 'proto_docs/google/iam/v3/policy_bindings_service.rb', line 86 class UpdatePolicyBindingRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |